package com.fossgalaxy.game.actions;

import com.fossgalaxy.game.orders.HealOrderRanged;
import com.fossgalaxy.games.tbs.GameState;
import com.fossgalaxy.games.tbs.actions.AbstractAction;
import com.fossgalaxy.games.tbs.entity.Entity;
import com.fossgalaxy.games.tbs.entity.HexagonTile;
import com.fossgalaxy.games.tbs.order.AttackOrderRanged;
import com.fossgalaxy.games.tbs.order.Order;
import com.fossgalaxy.games.tbs.ui.GameView;
import com.fossgalaxy.object.annotations.ObjectDef;
import org.codetome.hexameter.core.api.CubeCoordinate;
import org.codetome.hexameter.core.api.Hexagon;

import java.awt.*;
import java.awt.geom.Area;
import java.util.Collection;

/**
 * A ranged attack action.
 *
 * A ranged attack is an attack action that happens at a distance. The entity that is attacked doesn't get a counter
* attack (unlike melee attacks).
 */
public class RangeHealingAction extends AbstractAction {
    private static final Color HINT_HEAL_COLOUR = new Color(0, 174, 229, 50);
    private final int healAmount;

    @ObjectDef("HealRanged")
    public RangeHealingAction(int healAmount) {
        this.healAmount = healAmount;

    }
    // find range for the a close entity
    @Override
    public int getRange(Entity actor) {
        return 0;
    }

    @Override
    public Order generateOrder(CubeCoordinate co, GameState s) {
        Entity e = s.getEntityAt(co);
        if (e == null) {
            return null;
        }

        return new HealOrderRanged(healAmount);
    }


    @Override
    public boolean isPossible(Entity entity, GameState s, CubeCoordinate co) {
        //can't heal an empty spot
        Entity e = s.getEntityAt(co);
        if (e == null) {
            return false;
        }

         return e.equals(entity);
    }

    @Override
    public boolean isPossible(Entity entity, GameState s) {
        return true;
    }

    @Override
    public Color getHintColour() {
        return HINT_HEAL_COLOUR;
    }

    @Override
    public Color getBorderColour() {
        return Color.YELLOW;
    }

    public String toString() {
        return "Heal";
    }
}
